--[[
A generic button class

This code is MIT licensed, see http://www.opensource.org/licenses/mit-license.php
(C) 2010 - 2011 Gideros Mobile 
]]

ToggleButton = Core.class(Sprite)

function ToggleButton:init(upState, downState, group)
	self.group = group
	table.insert(group, self)
	self.selected = false

	self.upState = upState
	self.downState = downState
	self.focus = false

	self:updateVisualState(false)

	self:addEventListener(Event.MOUSE_DOWN, self.pressed, self)

	self:addEventListener(Event.TOUCHES_BEGIN, self.pressed, self)
	self:addEventListener(Event.TOUCHES_CANCEL, self.onTouchesCancel, self)
end

-- Select this ToggleButton and unselect all others
function ToggleButton:select()
	local group = self.group -- Our group
	for i = 1, #group do
		local other = group[i] -- Get next Toggle Button
		if other ~= self then
			other:updateVisualState(false) -- Set its state to be up
			other.selected = false
		end
	end
    self:updateVisualState(true) -- Set this Toggle Buttons state to be down
	self.selected = true
end

function ToggleButton:pressed(event)
	if event.x then
		if self:hitTestPoint(event.x, event.y) then
			event:stopPropagation()
			self.focus = event.id
			if not self.selected then
				self:select()
				self:dispatchEvent(Event.new("click"))
			end
		end
	end
end

function ToggleButton:onTouchesCancel(event)
	if self.focus then
		self.focus = false;
		event:stopPropagation()
	end
end

-- if state is true show downState else show upState
function ToggleButton:updateVisualState(state)
	if state then
		if self:contains(self.upState) then
			self:removeChild(self.upState)
		end
		
		if not self:contains(self.downState) then
			self:addChild(self.downState)
		end
	else
		if self:contains(self.downState) then
			self:removeChild(self.downState)
		end
		
		if not self:contains(self.upState) then
			self:addChild(self.upState)
		end
	end
end
